"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DirectionalDrilling = void 0;
var constants_1 = require("./constants");
var DirectionalDrilling = /** @class */ (function () {
    function DirectionalDrilling(args) {
        this._buildUpAngle = args.buildUpAngle;
        this._horizontalDisplacement = args.horizontalDisplacement;
        this._kickOffPoint = args.kickOffPoint;
        this._trueVerticalDepth = args.trueVerticalDepth;
    }
    DirectionalDrilling.prototype.build_UpAngleFxn = function (buildUpAngle) {
        return (constants_1.drillingConstants.valueOverbuildUp) /
            (buildUpAngle * constants_1.drillingConstants.valuetimesbuildUp);
    };
    DirectionalDrilling.prototype.horizontal_DisplacementFxn = function (horizontalDisplacementValue) {
        var angleX = (horizontalDisplacementValue - this.build_UpAngleFxn(this._buildUpAngle)) /
            (this._trueVerticalDepth - this._kickOffPoint);
        return this.toDegreesFxn(Math.atan(angleX));
    };
    DirectionalDrilling.prototype.total_AngleYFxn = function () {
        var angleY = this.build_UpAngleFxn(this._buildUpAngle) *
            Math.cos(this.toRadiansFxn(this.horizontal_DisplacementFxn(this._horizontalDisplacement))) /
            (this._trueVerticalDepth - this._kickOffPoint);
        return this.toDegreesFxn(Math.asin(angleY));
    };
    DirectionalDrilling.prototype.total_AngleXplusYFxn = function () {
        return this.total_AngleYFxn() + this.horizontal_DisplacementFxn(this._horizontalDisplacement);
    };
    DirectionalDrilling.prototype.measured_DepthAtEndOfBuildSectionFxn = function (kickoffPoint) {
        var setMeasuredDepth = this.total_AngleXplusYFxn() * constants_1.drillingConstants.valuetimesTotalAngleXplusY *
            constants_1.drillingConstants.PI * this.build_UpAngleFxn(this._buildUpAngle)
            /
                constants_1.drillingConstants.valueDividebyBuildUpAngle + kickoffPoint;
        return setMeasuredDepth;
    };
    DirectionalDrilling.prototype.trueVertical_DepthAtEndOfBuildFxn = function () {
        var trueVerticalDepthCompute = this.build_UpAngleFxn(this._buildUpAngle) *
            Math.sin(this.toRadiansFxn(this.total_AngleXplusYFxn()) + this._kickOffPoint);
        return trueVerticalDepthCompute;
    };
    DirectionalDrilling.prototype.horizontal_DeviationAtEndOfBuildUpFxn = function () {
        var radiusValue = this.build_UpAngleFxn(this._buildUpAngle);
        var cosValue = radiusValue * Math.cos(this.toRadiansFxn(this.total_AngleXplusYFxn()));
        return (radiusValue - cosValue);
    };
    DirectionalDrilling.prototype.total_MeasuredDepthFxn = function () {
        var totalMeasuredDepth = this._trueVerticalDepth - this._kickOffPoint;
        var Rsina = this.build_UpAngleFxn(this._buildUpAngle) * Math.sin(this.toRadiansFxn(this.total_AngleXplusYFxn()));
        var cosA = Math.cos(this.toRadiansFxn(this.total_AngleXplusYFxn()));
        var getTrueVerticalDepth = this.measured_DepthAtEndOfBuildSectionFxn(this._kickOffPoint);
        var setFromArcToTarget = (totalMeasuredDepth - Rsina) / cosA;
        var totalDepth = setFromArcToTarget + getTrueVerticalDepth;
        return totalDepth;
    };
    DirectionalDrilling.prototype.toDegreesFxn = function (radiansVal) {
        return radiansVal * (constants_1.drillingConstants.maxRadianValue / constants_1.drillingConstants.PI);
    };
    DirectionalDrilling.prototype.toRadiansFxn = function (degreesVal) {
        return degreesVal * (constants_1.drillingConstants.PI / constants_1.drillingConstants.maxRadianValue);
    };
    return DirectionalDrilling;
}());
exports.DirectionalDrilling = DirectionalDrilling;
var InitalizeDrillingData = {
    buildUpAngle: 2,
    horizontalDisplacement: 3000,
    kickOffPoint: 2000,
    trueVerticalDepth: 10000
};
var ddrilling = new DirectionalDrilling(InitalizeDrillingData);
console.log(ddrilling.build_UpAngleFxn(2));
console.log(ddrilling.horizontal_DisplacementFxn(3000));
console.log(ddrilling.total_AngleYFxn());
//# sourceMappingURL=DirectionalDrilling.js.map